@@ -101,6 +101,11 @@ class ContractType(mixins.PrintableType,babel.BabelNamed):
 class ContractTypes(dd.Table):
     model = ContractType
     column_names = 'name ref build_method template *'
+    detail_template = """
+    id name 
+    ref build_method template
+    ContractsByType
+    """
 
 
 
@@ -153,7 +158,8 @@ class ContractEndings(dd.Table):
 def contract_contact_choices(company):
     return contacts.Role.objects.filter(
         type__use_in_contracts=True,
-        company__id=company.pk)
+        company=company)
+        #~ company__id=company.pk)
 
 
 
@@ -173,6 +179,11 @@ class ContractBase(mixins.DiffingMixin,mixins.TypedPrintable,mixins.AutoUser):
         related_name="%(app_label)s_%(class)s_set_by_person",
         verbose_name=_("Person"))
         
+    company = models.ForeignKey(settings.LINO.company_model,
+        related_name="%(app_label)s_%(class)s_set_by_company",
+        verbose_name=_("Company"),
+        blank=True,null=True)
+        
     #~ contact = models.ForeignKey("links.Link",
       #~ related_name="%(app_label)s_%(class)s_set_by_contact",
       #~ blank=True,null=True,
@@ -227,7 +238,28 @@ class ContractBase(mixins.DiffingMixin,mixins.TypedPrintable,mixins.AutoUser):
         #~ # return msg % dict(pk=self.pk, person=self.person, company=self.company)
         #~ return msg % self.pk
         
+    def get_recipient(self):
+        if self.contact:
+            return self.contact
+        if self.company:
+            return self.company
+        return self.person
+    recipient = property(get_recipient)
         
+        
+        
+        
+    @chooser()
+    def contact_choices(cls,company):
+        if company is not None:
+            #~ return company.rolesbyparent.all()
+            #~ return company.rolesbyparent.filter(type__use_in_contracts=True)
+            #~ return links.Link.objects.filter(type__use_in_contracts=True,a=company)
+            #~ return contacts.Role.objects.filter(
+                #~ type__use_in_contracts=True,company=company)
+            return contract_contact_choices(company)
+        return []
+
     def dsbe_person(self):
         """Used in document templates."""
         if self.person_id is not None:
@@ -256,15 +288,19 @@ class ContractBase(mixins.DiffingMixin,mixins.TypedPrintable,mixins.AutoUser):
             if not self.exam_policy_id:
                 self.exam_policy_id = self.type.exam_policy_id
         if self.company:
-            if self.contact is None or self.contact.company != self.company:
+            if self.contact is None \
+              or self.contact.company is None \
+              or self.contact.company.pk != self.company.pk:
                 qs = contract_contact_choices(self.company)
                 #~ qs = self.company.rolesbyparent.all()
                 if qs.count() == 1:
                     self.contact = qs[0]
                 else:
+                    #~ print "20120227 clear contact!"
                     self.contact = None
-        # severe test is ready but not yet activated :
-        if False and self.person_id is not None:
+        # The severe test is ready but not yet activated :
+        if False:
+          if self.person_id is not None:
             msg = OverlappingContractsTest(self.person).check(self)
             if msg:
                 raise ValidationError(msg)
@@ -412,10 +448,6 @@ class Contract(ContractBase):
         related_name="%(app_label)s_%(class)s_set_by_type",
         verbose_name=_("Contract Type"),blank=True)
     
-    company = models.ForeignKey(settings.LINO.company_model,
-        verbose_name=_("Company"),
-        blank=True,null=True)
-        
     stages = dd.RichTextField(_("stages"),
         blank=True,null=True,format='html')
     goals = dd.RichTextField(_("goals"),
@@ -447,30 +479,37 @@ class Contract(ContractBase):
             'date_decided date_issued ')
         #~ super(Contract,cls).site_setup(lino)
         
-    @chooser()
-    def contact_choices(cls,company):
-        if company is not None:
-            #~ return company.rolesbyparent.all()
-            #~ return company.rolesbyparent.filter(type__use_in_contracts=True)
-            #~ return links.Link.objects.filter(type__use_in_contracts=True,a=company)
-            return contract_contact_choices(company)
-        return []
-
-    def get_recipient(self):
-        if self.contact:
-            return self.contact
-        if self.company:
-            return self.company
-        return self.person
-    recipient = property(get_recipient)
-        
     def disabled_fields(self,request):
         #~ if self.must_build:
         if not self.build_time:
             return []
         #~ return df + settings.LINO.CONTRACT_PRINTABLE_FIELDS
         return self.PRINTABLE_FIELDS
-  
+
+
+class ContractDetail(dd.DetailLayout):    
+    general = """
+    id:8 person:25 user:15 user_asd:15 language:8
+    type company contact:20     
+    applies_from applies_until exam_policy
+    
+    date_decided date_issued 
+    date_ended ending
+    cal.TasksByOwner cal.EventsByOwner
+    """
+    
+    isip = """
+    stages        goals
+    duties_asd    duties_dsbe
+    duties_company duties_person
+    """
+    
+    main = "general isip"
+    
+    def setup_handle(self,dh):
+        dh.general.label = _("General")
+        dh.isip.label = _("ISIP")
+
 
 class Contracts(dd.Table):
     model = Contract
@@ -478,6 +517,7 @@ class Contracts(dd.Table):
     order_by = ['id']
     #~ active_fields = ('company','contact')
     active_fields = ['company']
+    detail_layout = ContractDetail()
     
 class ContractsByPerson(Contracts):
     master_key = 'person'
@@ -489,9 +529,10 @@ class ContractsByType(Contracts):
     column_names = "applies_from person user *"
     order_by = ["applies_from"]
 
-class MyContracts(mixins.ByUser,Contracts):
+class MyContracts(Contracts,mixins.ByUser):
     column_names = "applies_from person *"
-    label = _("My PIIS contracts")
+    #~ label = _("My ISIP contracts")
+    #~ label = _("My PIIS contracts")
     #~ order_by = "reminder_date"
     #~ column_names = "reminder_date person company *"
     order_by = ["applies_from"]
